@@ -13,8 +13,8 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
+ *
  */
 
 #ifndef __DataImpl_h__
@@ -27,30 +27,41 @@
 #include <vector>
 #include <deque>
 
-#include <pan/general/foreach.h>
+#include <pan/tasks/queue.h>
 #include <pan/general/quark.h>
+#include <pan/general/macros.h>
 #include <pan/general/map-vector.h>
 #include <pan/general/sorted-vector.h>
 #include <pan/usenet-utils/numbers.h>
+#include <pan/usenet-utils/scorefile.h>
+#include <pan/usenet-utils/blowfish.h>
 #include <pan/data/article.h>
 #include <pan/data/article-cache.h>
+#include <pan/data/encode-cache.h>
 #include <pan/data/data.h>
-#include <pan/data/scorefile.h>
-#include <pan/tasks/queue.h>
 #include <pan/data-impl/data-io.h>
 #include <pan/data-impl/article-filter.h>
+#include <pan/data-impl/rules-filter.h>
 #include <pan/data-impl/profiles.h>
+#include <pan/data-impl/memchunk.h>
+#include <pan/gui/prefs.h>
+
+#ifdef HAVE_GNUTLS
+  #include <pan/data/cert-store.h>
+  #include <gnutls/gnutls.h>
+#endif
 
 namespace pan
 {
   typedef std::vector<const Article*> articles_t;
+  typedef Data::PasswordData PasswordData;
 
   /**
    * File-based implementation of the `Data' backend interface.
    *
    * Most of the files are stored in $PAN_HOME, which defaults to
    * $HOME/.pan2 if the PAN_HOME environmental variable isn't set.
-   * 
+   *
    * @ingroup data_impl
    */
   class DataImpl:
@@ -58,26 +69,57 @@ namespace pan
     public TaskArchive,
     public ProfilesImpl
   {
+
     /**
     *** SERVERS
     **/
 
     public:
-      DataImpl (bool unit_test=false, int cache_megs=10, DataIO * source=new DataIO());
+      /* The ProfilesImpl will own and destruct the DataIO object */
+      DataImpl (const StringView& cache_ext, Prefs& prefs, bool unit_test=false, int cache_megs=10, DataIO * source=new DataIO());
       virtual ~DataImpl ();
       virtual void save_state ();
 
     public:
       virtual ArticleCache& get_cache () { return _cache; }
       virtual const ArticleCache& get_cache () const { return _cache; }
+
+      virtual EncodeCache& get_encode_cache () { return _encode_cache; }
+      virtual const EncodeCache& get_encode_cache () const { return _encode_cache; }
+
+      virtual CertStore& get_certstore () { return _certstore; }
+      virtual const CertStore& get_certstore () const { return _certstore; }
+
+      virtual Prefs& get_prefs () { return _prefs; }
+      virtual const Prefs& get_prefs () const { return _prefs; }
+
+      virtual Queue* get_queue () { return _queue; }
+      virtual const Queue* get_queue () const { return _queue; }
+
+      virtual void set_queue (Queue* q) { _queue = q; }
+
     private:
       ArticleCache _cache;
+      EncodeCache _encode_cache;
+      CertStore _certstore;
+      Queue* _queue;
 
+    public:
+#ifdef HAVE_GKR
+#if GTK_CHECK_VERSION(3,0,0)
+      gboolean password_encrypt (const PasswordData&);
+      gchar* password_decrypt (PasswordData&) const;
+#else
+      GnomeKeyringResult password_encrypt (const PasswordData&);
+      GnomeKeyringResult password_decrypt (PasswordData&) const;
+#endif /* GTK_CHECK_VERSION(3,0,0) */
+#endif
     private:
 
       void rebuild_backend ();
       const bool _unit_test;
       DataIO * _data_io;
+      Prefs& _prefs;
 
     /**
     *** SERVERS
@@ -87,29 +129,16 @@ namespace pan
 
       void load_server_properties (const DataIO&);
 
-      void save_server_properties (DataIO&) const;
-
-      struct Server
-      {
-         std::string username;
-         std::string password;
-         std::string host;
-         int port;
-         int article_expiration_age;
-         int max_connections;
-         int rank;
-         typedef sorted_vector<Quark,true,AlphabeticalQuarkOrdering> groups_t;
-         groups_t groups;
-
-         Server(): port(119), article_expiration_age(31), max_connections(2), rank(1) {}
-      };
+      void save_server_properties (DataIO&, Prefs&);
 
       typedef Loki::AssocVector<Quark,Server> servers_t;
 
       servers_t _servers;
 
-      Server* find_server (const Quark& server);
-      const Server* find_server (const Quark& server) const;
+    public:
+      virtual const Server* find_server (const Quark& server) const;
+      virtual Server* find_server (const Quark& server);
+      virtual bool find_server_by_hn (const std::string& server, Quark& setme) const;
 
     public: // mutators
 
@@ -120,20 +149,33 @@ namespace pan
 
       virtual void set_server_auth (const Quark       & server,
                                     const StringView  & username,
-                                    const StringView  & password);
-                                                                                
+                                    gchar             *&password,
+                                    bool                use_gkr);
+
+      virtual void set_server_trust (const Quark      & servername,
+                                     int                setme);
+
       virtual void set_server_addr (const Quark       & server,
                                     const StringView  & host,
                                     const int           port);
-                                                                                
+
       virtual void set_server_limits (const Quark     & server,
                                       int               max_connections);
 
       virtual void set_server_rank (const Quark& server, int rank);
 
+      virtual void set_server_ssl_support (const Quark& server, int ssl);
+
+      virtual void set_server_cert (const Quark & server, const StringView & cert);
+
       virtual void set_server_article_expiration_age  (const Quark  & server,
                                                        int            days);
 
+      virtual void set_server_compression_type  (const Quark   & server,
+                                                 const int       setme);
+
+      virtual void save_server_info (const Quark& server);
+
     public: // accessors
 
       virtual quarks_t get_servers () const {
@@ -145,14 +187,23 @@ namespace pan
 
       virtual bool get_server_auth (const Quark   & server,
                                     std::string   & setme_username,
-                                    std::string   & setme_password) const;
-                                                                                
+                                    gchar         *&setme_password,
+                                    bool            use_gkr);
+
+      virtual bool get_server_trust (const Quark  & servername, int&) const;
+
+      virtual bool get_server_compression_type (const Quark  & servername, CompressionType&) const;
+
       virtual bool get_server_addr (const Quark   & server,
                                     std::string   & setme_host,
                                     int           & setme_port) const;
 
       virtual std::string get_server_address (const Quark& servername) const;
 
+      virtual bool get_server_ssl_support (const Quark & server) const;
+
+      virtual std::string get_server_cert (const Quark & server) const;
+
       virtual int get_server_rank (const Quark& server) const;
 
       virtual int get_server_limits (const Quark & server) const;
@@ -197,7 +248,7 @@ namespace pan
          */
         struct Server {
           Numbers _read;
-          unsigned long _xover_high;
+          uint64_t _xover_high;
           Server(): _xover_high(0) {}
         };
         typedef Loki::AssocVector<Quark,Server> servers_t;
@@ -296,7 +347,11 @@ namespace pan
           local GroupHeaders.  As a side-effect, the value of `part'
           after this call is undefined.  This is an ugly interface,
           but it's fast and only called by one client. */
-      void load_part (const Quark& g, const Quark& mid, size_t number, size_t lines, Article::Part& part);
+      void load_part (const Quark& g, const Quark& mid,
+                      int number,
+                      const StringView& part_mid,
+                      unsigned long lines,
+                      unsigned long bytes);
 
       void load_headers (const DataIO&, const Quark& group);
       void save_headers (DataIO&, const Quark& group) const;
@@ -347,13 +402,18 @@ namespace pan
         }
       };
 
+      /***
+       **
+      ***/
+      virtual void fire_article_flag_changed (articles_t& a, const Quark& group);
+
       struct GroupHeaders
       {
         int _ref;
         bool _dirty;
         nodes_t _nodes;
-        std::deque<Article> _art_chunk;
-        std::deque<ArticleNode> _node_chunk;
+        MemChunk<Article> _art_chunk;
+        MemChunk<ArticleNode> _node_chunk;
 
         GroupHeaders();
         ~GroupHeaders ();
@@ -372,6 +432,7 @@ namespace pan
         const Article* find_article (const Quark& mid) const;
         void remove_articles (const quarks_t& mids);
         void build_references_header (const Article* article, std::string& setme) const;
+
       };
 
       static void find_nodes (const quarks_t           & mids,
@@ -416,8 +477,10 @@ namespace pan
         public: // life cycle
           MyTree (DataImpl              & data_impl,
                   const Quark           & group,
+                  const Quark           & save_path,  // for auto-download
                   const Data::ShowType    show_type,
-                  const FilterInfo      * filter_info);
+                  const FilterInfo      * filter_info=0,
+                  const RulesInfo       * rules=0);
           virtual ~MyTree ();
 
         public: // from ArticleTree
@@ -427,6 +490,8 @@ namespace pan
           virtual size_t size () const;
           virtual void set_filter (const ShowType      show_type = SHOW_ARTICLES,
                                    const FilterInfo  * criteria  = 0);
+          virtual void set_rules  (const ShowType      show_type = SHOW_ARTICLES,
+                                   const RulesInfo   * rules  = 0);
 
         public:
           void articles_changed (const quarks_t& mids, bool do_refilter);
@@ -436,9 +501,11 @@ namespace pan
         private: // implementation fields
           const Quark _group;
           DataImpl & _data;
+          const Quark _save_path;  // for auto-download
           nodes_t _nodes;
-          std::deque<ArticleNode> _node_chunk;
+          MemChunk<ArticleNode> _node_chunk;
           FilterInfo _filter;
+          RulesInfo _rules;
           Data::ShowType _show_type;
           struct NodeMidCompare;
           struct TwoNodes;
@@ -448,23 +515,32 @@ namespace pan
           void accumulate_descendants (unique_nodes_t&, const ArticleNode*) const;
           void add_articles (const const_nodes_v&);
           void apply_filter (const const_nodes_v&);
+          void apply_rules  (const_nodes_v& candidates);
+
+        private:
+          void cache_articles (std::set<const Article*> s);
+          void download_articles (std::set<const Article*> s);
+
       };
 
+
+
       std::set<MyTree*> _trees;
       void on_articles_removed (const quarks_t& mids) const;
       void on_articles_added (const Quark& group, const quarks_t& mids);
-      void on_articles_changed (const quarks_t& mids, bool do_refilter) const;
+      void on_articles_changed (const Quark& group, const quarks_t& mids, bool do_refilter);
       void remove_articles_from_tree (MyTree*, const quarks_t& mids) const;
       void add_articles_to_tree (MyTree*, const quarks_t& mids);
 
-
     public:  // Data interface
 
       virtual void delete_articles             (const unique_articles_t&);
 
       virtual ArticleTree* group_get_articles  (const Quark        & group,
+                                                const Quark        & save_path,
                                                 const ShowType      show_type = SHOW_ARTICLES,
-                                                const FilterInfo   * criteria=0) const;
+                                                const FilterInfo   * criteria=0,
+                                                const RulesInfo    * rules=0) const;
 
       virtual void group_clear_articles        (const Quark        & group);
 
@@ -495,8 +571,14 @@ namespace pan
                                                size_t                end_line,
                                                bool                  do_rescore);
 
+      virtual void rescore_articles (const Quark& group, const quarks_t mids);
+
+      virtual void rescore_group_articles (const Quark& group);
+
       virtual void rescore ();
 
+      virtual std::string get_scorefile_name() const;
+
     private:
 
       Scorefile _scorefile;
@@ -512,7 +594,7 @@ namespace pan
        */
       struct XOverEntry
       {
-        int _batch_parts_size;
+        time_t _last_flush_time;
 
         /** These are the articles which have been recently added.
             The patch is periodically flushed to on_articles_added()
@@ -536,10 +618,7 @@ namespace pan
             be assigned to the same XOVER task. */
         int refcount;
 
-        /** This is for scoring the articles. */
-        ArticleFilter::sections_t score_sections;
-
-        XOverEntry(): _batch_parts_size(0), refcount(0) { }
+        XOverEntry(): _last_flush_time(0), refcount(0) { }
       };
 
       typedef Loki::AssocVector<Quark,XOverEntry> xovers_t;
@@ -570,25 +649,29 @@ namespace pan
                                          const Quark          & group,
                                          const StringView     & subject,
                                          const StringView     & author,
-                                         const StringView     & date,
+                                         const time_t           date,
                                          const StringView     & message_id,
                                          const StringView     & references,
                                          const unsigned long    byte_count,
                                          const unsigned long    line_count,
-                                         const StringView     & xref);
+                                         const StringView     & xref,
+                                         const bool             is_virtual=false);
 
-      virtual void xover_unref   (const Quark          & group);
+      /** useful for xover unit testing */
+      virtual void xover_flush   (const Quark           & group);
 
-      virtual unsigned long get_xover_high (const Quark  & group,
-                                    const Quark  & server) const;
+      virtual void xover_unref   (const Quark           & group);
 
-      virtual void set_xover_high (const Quark  & group,
-                                   const Quark  & server,
-                                   const unsigned long    high);
+      virtual uint64_t get_xover_high (const Quark & group,
+                                       const Quark & server) const;
 
-       virtual void set_xover_low (const Quark    & group,
-                                   const Quark    & server,
-                                   const unsigned long    low);
+      virtual void set_xover_high (const Quark          & group,
+                                   const Quark          & server,
+                                   const uint64_t         high);
+
+       virtual void set_xover_low (const Quark          & group,
+                                   const Quark          & server,
+                                   const uint64_t         low);
 
 
     /**
@@ -606,6 +689,21 @@ namespace pan
     public:
 
       const ArticleFilter _article_filter;
+            RulesFilter   _rules_filter;
+
+    private:
+      mutable guint newsrc_autosave_id;
+      guint newsrc_autosave_timeout;
+    public:
+      void set_newsrc_autosave_timeout(guint seconds)
+        {newsrc_autosave_timeout = seconds;}
+      void save_newsrc_files()
+      { // Called from  rc_as_cb(...).
+        // The newsrc_autosave_id is now (soon) invalid since the timeout will be
+        // cancelled when our caller returns FALSE. So forget about it already.
+        newsrc_autosave_id = 0;
+        save_newsrc_files(*_data_io);
+      }
   };
 }
 
