@@ -439,7 +439,12 @@ namespace
         expandme.push_back (store->get_iter (row));
     }
 
-    setme_rows.sort ();
+    //Use a stable sort to ensure that if there are newsgroups called Sent
+    //or Drafts on the server (yes, it does happen!) and you have the local
+    //version selected on exit, it reselects the local one on restart.
+    //With normal sort, a random one of the two is picked, which is seriously
+    //disconcerting.
+    setme_rows.stable_sort ();
     return store;
   }
 }
