@@ -33,12 +33,14 @@
 #include <pan/gui/group-prefs.h>
 #include <pan/gui/wait.h>
 
+#include <memory>
 #include <stdint.h>
 
 #include "gtk-compat.h"
 
 namespace pan
 {
+  class EditorSpawner;
   class GroupPane;
   class HeaderPane;
   class BodyPane;
@@ -198,6 +200,7 @@ namespace pan
       virtual void do_refresh_groups ();
       virtual void do_subscribe_selected_groups ();
       virtual void do_unsubscribe_selected_groups ();
+      virtual void do_edit_scores(GtkAction *);
 #ifdef HAVE_GNUTLS
       void do_show_cert_failed_dialog(VerifyData* data);
       bool confirm_accept_new_cert_dialog(GtkWindow*, gnutls_x509_crt_t, const Quark&);
@@ -287,7 +290,7 @@ namespace pan
 
       void score_add (int);
 
-      static void notebook_page_switched_cb (GtkNotebook*, GtkNotebookPage*, gint, gpointer);
+      static void notebook_page_switched_cb (GtkNotebook*, void *, gint, gpointer);
 
       static void root_realized_cb (GtkWidget*, gpointer self_gpointer);
 
@@ -305,6 +308,10 @@ namespace pan
       static void prefs_dialog_destroyed_cb (GtkWidget * w, gpointer self);
       void prefs_dialog_destroyed (GtkWidget* w);
       int score_int_from_string(std::string val, const char* rules[]);
+
+      void edit_scores_cleanup(int, char *, GtkAction *);
+      std::unique_ptr<EditorSpawner> _spawner;
+
 #ifdef HAVE_GNUTLS
       static gboolean show_cert_failed_cb(gpointer gp);
 #endif
