@@ -34,6 +34,10 @@
 #include "e-charset-dialog.h"
 #include "actions-extern.h"
 
+extern "C" {
+  #include <sys/stat.h>
+}
+
 #include <algorithm>
 
 using namespace pan;
@@ -63,7 +67,7 @@ namespace pan
 
     state = event->state & gtk_accelerator_get_default_mod_mask();
 
-    if (event->keyval == GDK_Escape)
+    if (event->keyval == GDK_KEY_Escape)
       return FALSE;	/* close the dialog, don't allow escape when detecting keybindings. */
 
     str = gtk_accelerator_name(event->keyval, GdkModifierType(state));
@@ -1279,7 +1283,7 @@ PrefsDialog :: PrefsDialog (Prefs& prefs, GtkWindow* parent):
     pan_box_pack_start_defaults (GTK_BOX(h), new_color_button ("text-color-bg", def_color_str, prefs));
     HIG :: workarea_add_row (t, &row, _("Text Color:"), h);
   HIG :: workarea_finish (t, &row);
-	
+
   gtk_notebook_append_page (GTK_NOTEBOOK(notebook), t, new_label_with_icon(_("_Colors"), _("Colors"), icon_prefs_colors, prefs));
 
   // Applications
